@@ -40,13 +40,13 @@
 
 /* private class data
  */
-struct NAModuleClassPrivate {
+struct _NAModuleClassPrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct NAModulePrivate {
+struct _NAModulePrivate {
 	gboolean  dispose_has_run;
 	gchar    *path;						/* full pathname of the plugin */
 	gchar    *name;						/* basename without the extension */
@@ -198,7 +198,7 @@ instance_finalize( GObject *object )
 	}
 }
 
-/**
+/*
  * na_module_dump:
  * @module: this #NAModule instance.
  *
@@ -219,7 +219,7 @@ na_module_dump( const NAModule *module )
 	}
 }
 
-/**
+/*
  * na_module_load_modules:
  *
  * Load availables dynamically loadable extension libraries (plugins).
@@ -328,6 +328,11 @@ module_load( GTypeModule *gmodule )
  * the module has been successfully loaded
  * is it a Nautilus-Action plugin ?
  * if ok, we ask the plugin to initialize itself
+ *
+ * As of API v 1:
+ * - na_extension_startup, na_extension_list_types and na_extension_shutdown
+ *   are mandatory, and MUST be implemented by the plugin
+ * - na_extension_get_version is optional, and defaults to 1.
  */
 static gboolean
 is_a_na_plugin( NAModule *module )
@@ -338,6 +343,7 @@ is_a_na_plugin( NAModule *module )
 	ok =
 		plugin_check( module, "na_extension_startup"    , ( gpointer * ) &module->private->startup) &&
 		plugin_check( module, "na_extension_list_types" , ( gpointer * ) &module->private->list_types ) &&
+		plugin_check( module, "na_extension_shutdown"   , ( gpointer * ) &module->private->shutdown ) &&
 		module->private->startup( G_TYPE_MODULE( module ));
 
 	if( ok ){
@@ -443,7 +449,7 @@ module_unload( GTypeModule *gmodule )
 	module->private->shutdown = NULL;
 }
 
-/**
+/*
  * na_module_get_extensions_for_type:
  * @type: the serched GType.
  *
@@ -469,7 +475,7 @@ na_module_get_extensions_for_type( GList *modules, GType type )
 	return( g_list_reverse( willing_to ));
 }
 
-/**
+/*
  * na_module_free_extensions_list:
  * @extensions: a #GList as returned by #na_module_get_extensions_for_type().
  *
@@ -482,7 +488,7 @@ na_module_free_extensions_list( GList *extensions )
 	g_list_free( extensions );
 }
 
-/**
+/*
  * na_module_has_id:
  * @module: this #NAModule object.
  * @id: the searched id.
@@ -504,7 +510,7 @@ na_module_has_id( NAModule *module, const gchar *id )
 	return( id_ok );
 }
 
-/**
+/*
  * na_module_release_modules:
  * @modules: the list of loaded modules.
  *
