@@ -43,12 +43,15 @@
 
 G_BEGIN_DECLS
 
-void       nact_gtk_utils_set_editable( GtkObject *widget, gboolean editable );
+void       nact_gtk_utils_set_editable( GObject *widget, gboolean editable );
+
+void       nact_gtk_utils_set_initial_state  ( GtkToggleButton *button, GCallback func );
+void       nact_gtk_utils_reset_initial_state( GtkToggleButton *button, GCallback func, void *data, gboolean active );
 
 /* image utilities
  */
-GdkPixbuf *nact_gtk_utils_get_pixbuf( const gchar *name, GtkWidget *widget, gint size );
-void       nact_gtk_utils_render( const gchar *name, GtkImage *widget, gint size );
+GdkPixbuf *nact_gtk_utils_get_pixbuf( const gchar *name, GtkWidget *widget, GtkIconSize size );
+void       nact_gtk_utils_render( const gchar *name, GtkImage *widget, GtkIconSize size );
 
 /* standard dialog boxes
  */
@@ -57,6 +60,12 @@ void       nact_gtk_utils_select_file( BaseWindow *window,
 				GtkWidget *entry, const gchar *entry_name,
 				const gchar *default_dir_uri );
 
+void       nact_gtk_utils_select_file_with_preview( BaseWindow *window,
+				const gchar *title, const gchar *dialog_name,
+				GtkWidget *entry, const gchar *entry_name,
+				const gchar *default_dir_uri,
+				GCallback update_preview_cb );
+
 void       nact_gtk_utils_select_dir( BaseWindow *window,
 				const gchar *title, const gchar *dialog_name,
 				GtkWidget *entry, const gchar *entry_name,
