@@ -161,7 +161,7 @@ static void     instance_set_property( GObject *object, guint property_id, const
 static void     instance_dispose( GObject *application );
 static void     instance_finalize( GObject *application );
 
-static void     actually_delete_item( NactMainWindow *window, NAObject *item, NAUpdater *updater );
+static gboolean actually_delete_item( NactMainWindow *window, NAObject *item, NAUpdater *updater, GList **not_deleted, GSList **messages );
 
 static gchar   *base_get_toplevel_name( const BaseWindow *window );
 static gchar   *base_get_iprefs_window_id( const BaseWindow *window );
@@ -174,10 +174,10 @@ static void     on_main_window_level_zero_order_changed( NactMainWindow *window,
 static void     on_iactions_list_selection_changed( NactIActionsList *instance, GSList *selected_items );
 static void     on_iactions_list_status_changed( NactMainWindow *window, gpointer user_data );
 static void     raz_main_properties( NactMainWindow *window );
-static void     set_current_object_item( NactMainWindow *window, GSList *selected_items );
-static void     set_current_profile( NactMainWindow *window, gboolean set_action, GSList *selected_items );
-static gchar   *iactions_list_get_treeview_name( NactIActionsList *instance );
+static void     setup_current_selection( NactMainWindow *window, NAObjectId *selected_row );
 static void     setup_dialog_title( NactMainWindow *window );
+static void     setup_writability_status( NactMainWindow *window );
+static gchar   *iactions_list_get_treeview_name( NactIActionsList *instance );
 
 static void     on_tab_updatable_item_updated( NactMainWindow *window, gpointer user_data, gboolean force_display );
 
@@ -187,7 +187,9 @@ static void     install_autosave( NactMainWindow *window );
 static void     ipivot_consumer_on_autosave_changed( NAIPivotConsumer *instance, gboolean enabled, guint period );
 static void     ipivot_consumer_on_items_changed( NAIPivotConsumer *instance, gpointer user_data );
 static void     ipivot_consumer_on_display_order_changed( NAIPivotConsumer *instance, gint order_mode );
+static void     ipivot_consumer_on_io_provider_prefs_changed( NAIPivotConsumer *instance );
 static void     ipivot_consumer_on_mandatory_prefs_changed( NAIPivotConsumer *instance );
+static void     update_ui_after_provider_change( NactMainWindow *window );
 static void     reload( NactMainWindow *window );
 
 static gchar   *iabout_get_application_name( NAIAbout *instance );
@@ -612,6 +614,7 @@ ipivot_consumer_iface_init( NAIPivotConsumerInterface *iface )
 	iface->on_create_root_menu_changed = NULL;
 	iface->on_display_about_changed = NULL;
 	iface->on_display_order_changed = ipivot_consumer_on_display_order_changed;
+	iface->on_io_provider_prefs_changed = ipivot_consumer_on_io_provider_prefs_changed;
 	iface->on_items_changed = ipivot_consumer_on_items_changed;
 	iface->on_mandatory_prefs_changed = ipivot_consumer_on_mandatory_prefs_changed;
 }
@@ -662,6 +665,8 @@ instance_init( GTypeInstance *instance, gpointer klass )
 			G_CALLBACK( on_tab_updatable_item_updated ));
 
 	self->private->dispose_has_run = FALSE;
+
+	na_ipivot_consumer_allow_notify( NA_IPIVOT_CONSUMER( instance ), TRUE, 0 );
 }
 
 static void
@@ -973,34 +978,57 @@ nact_main_window_reload( NactMainWindow *window )
 /**
  * nact_main_window_remove_deleted:
  * @window: this #NactMainWindow instance.
+ * @messages: a pointer to a #GSList of error messages.
  *
  * Removes the deleted items from the underlying I/O storage subsystem.
+ *
+ * Each item of <structfield>NactMainWindow::private::deleted</structfield>
+ * #GList may actually itself be a tree (e.g. a #NAObjectMenu). The embedded
+ * items will be recursivelly removed, starting from the root.
+ *
+ * Returns: %TRUE if all candidate items have been successfully deleted,
+ * %FALSE else.
+ *
+ * @messages #GSList is only filled up in case of an error has occured.
+ * If there is no error (nact_main_window_remove_deleted() returns %TRUE),
+ * then the caller may safely assume that @messages is returned in the
+ * same state that it has been provided.
  */
-void
-nact_main_window_remove_deleted( NactMainWindow *window )
+gboolean
+nact_main_window_remove_deleted( NactMainWindow *window, GSList **messages )
 {
+	gboolean delete_ok = TRUE;
 	NactApplication *application;
 	NAUpdater *updater;
 	GList *it;
 	NAObject *item;
+	GList *not_deleted;
 
-	g_return_if_fail( NACT_IS_MAIN_WINDOW( window ));
+	g_return_val_if_fail( NACT_IS_MAIN_WINDOW( window ), FALSE );
 
 	if( !window->private->dispose_has_run ){
 
 		application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
 		updater = nact_application_get_updater( application );
+		not_deleted = NULL;
 
 		for( it = window->private->deleted ; it ; it = it->next ){
 			item = NA_OBJECT( it->data );
-			actually_delete_item( window, item, updater );
+			delete_ok = actually_delete_item( window, item, updater, &not_deleted, messages );
 		}
 
 		na_object_unref_items( window->private->deleted );
 		window->private->deleted = NULL;
 
 		setup_dialog_title( window );
+
+		if( g_list_length( not_deleted )){
+			nact_iactions_list_bis_insert_items( NACT_IACTIONS_LIST( window ), not_deleted, NULL );
+			na_object_unref_items( not_deleted );
+		}
 	}
+
+	return( delete_ok );
 }
 
 /*
@@ -1008,31 +1036,43 @@ nact_main_window_remove_deleted( NactMainWindow *window )
  * action has been marked as modified when the profile has been deleted,
  * and thus updated in the storage subsystem as well as in the pivot
  */
-static void
-actually_delete_item( NactMainWindow *window, NAObject *item, NAUpdater *updater )
+static gboolean
+actually_delete_item( NactMainWindow *window, NAObject *item, NAUpdater *updater, GList **not_deleted, GSList **messages )
 {
+	gboolean delete_ok = TRUE;
 	GList *items, *it;
 	NAObject *origin;
+	gchar *msg;
 
 	g_debug( "nact_main_window_actually_delete_item: item=%p (%s)",
 			( void * ) item, G_OBJECT_TYPE_NAME( item ));
 
 	if( NA_IS_OBJECT_ITEM( item )){
-		nact_window_delete_item( NACT_WINDOW( window ), NA_OBJECT_ITEM( item ));
+		msg = NULL;
+		delete_ok = nact_window_delete_item( NACT_WINDOW( window ), NA_OBJECT_ITEM( item ), &msg );
 
-		if( NA_IS_OBJECT_MENU( item )){
+		if( !delete_ok ){
+			*messages = g_slist_append( *messages, msg );
+			*not_deleted = g_list_append( *not_deleted, na_object_ref( item ));
+			g_free( msg );
+
+		} else if( NA_IS_OBJECT_MENU( item )){
 			items = na_object_get_items( item );
-			for( it = items ; it ; it = it->next ){
-				actually_delete_item( window, NA_OBJECT( it->data ), updater );
+			for( it = items ; delete_ok && it ; it = it->next ){
+				delete_ok &= actually_delete_item( window, NA_OBJECT( it->data ), updater, not_deleted, messages );
 			}
 		}
 
-		origin = ( NAObject * ) na_object_get_origin( item );
-		if( origin ){
-			na_updater_remove_item( updater, origin );
-			g_object_unref( origin );
+		if( delete_ok ){
+			origin = ( NAObject * ) na_object_get_origin( item );
+			if( origin ){
+				na_updater_remove_item( updater, origin );
+				g_object_unref( origin );
+			}
 		}
 	}
+
+	return( delete_ok );
 }
 
 static gchar *
@@ -1228,10 +1268,7 @@ on_iactions_list_selection_changed( NactIActionsList *instance, GSList *selected
 {
 	static const gchar *thisfn = "nact_main_window_on_iactions_list_selection_changed";
 	NactMainWindow *window;
-	NAObject *object;
 	gint count;
-	NactApplication *application;
-	NAUpdater *updater;
 
 	count = g_slist_length( selected_items );
 
@@ -1248,32 +1285,22 @@ on_iactions_list_selection_changed( NactIActionsList *instance, GSList *selected
 
 	if( count == 1 ){
 		g_return_if_fail( NA_IS_OBJECT_ID( selected_items->data ));
-		object = NA_OBJECT( selected_items->data );
-
-		if( NA_IS_OBJECT_ITEM( object )){
-			window->private->selected_item = NA_OBJECT_ITEM( object );
-			set_current_object_item( window, selected_items );
-
-		} else {
-			g_assert( NA_IS_OBJECT_PROFILE( object ));
-			window->private->selected_profile = NA_OBJECT_PROFILE( object );
-			set_current_profile( window, TRUE, selected_items );
-		}
-
-		application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( instance )));
-		updater = nact_application_get_updater( application );
-		window->private->editable = na_updater_is_item_writable( updater, window->private->selected_item, &window->private->reason );
-		nact_main_statusbar_set_locked( window, !window->private->editable, window->private->reason );
-
-	} else {
-		set_current_object_item( window, selected_items );
+		setup_current_selection( window, NA_OBJECT_ID( selected_items->data ));
+		setup_writability_status( window );
 	}
 
 	setup_dialog_title( window );
-
 	g_signal_emit_by_name( window, MAIN_WINDOW_SIGNAL_SELECTION_CHANGED, GINT_TO_POINTER( count ));
 }
 
+static void
+on_iactions_list_status_changed( NactMainWindow *window, gpointer user_data )
+{
+	g_debug( "nact_main_window_on_iactions_list_status_changed" );
+
+	setup_dialog_title( window );
+}
+
 static void
 raz_main_properties( NactMainWindow *window )
 {
@@ -1285,79 +1312,33 @@ raz_main_properties( NactMainWindow *window )
 	nact_main_statusbar_set_locked( window, FALSE, 0 );
 }
 
-static void
-on_iactions_list_status_changed( NactMainWindow *window, gpointer user_data )
-{
-	g_debug( "nact_main_window_on_iactions_list_status_changed" );
-
-	setup_dialog_title( window );
-}
-
 /*
- * update the notebook when selection changes in ActionsList
- * if there is only one profile, we also setup the profile
- * count_profiles may be null (invalid action)
+ * enter after raz_properties
+ * only called when only one selected row
  */
 static void
-set_current_object_item( NactMainWindow *window, GSList *selected_items )
+setup_current_selection( NactMainWindow *window, NAObjectId *selected_row )
 {
-	static const gchar *thisfn = "nact_main_window_set_current_object_item";
-	gint count_profiles;
+	guint nb_profiles;
 	GList *profiles;
-	/*NAObject *current;*/
 
-	g_debug( "%s: window=%p, current=%p, selected_items=%p",
-			thisfn, ( void * ) window, ( void * ) window->private->selected_item, ( void * ) selected_items );
+	if( NA_IS_OBJECT_PROFILE( selected_row )){
+		window->private->selected_profile = NA_OBJECT_PROFILE( selected_row );
+		window->private->selected_item = NA_OBJECT_ITEM( na_object_get_parent( selected_row ));
 
-	/* set the profile to be displayed, if any
-	 */
-	window->private->selected_profile = NULL;
+	} else {
+		g_return_if_fail( NA_IS_OBJECT_ITEM( selected_row ));
+		window->private->selected_item = NA_OBJECT_ITEM( selected_row );
 
-	if( window->private->selected_item ){
+		if( NA_IS_OBJECT_ACTION( selected_row )){
+			nb_profiles = na_object_get_items_count( selected_row );
 
-		if( NA_IS_OBJECT_ACTION( window->private->selected_item )){
-
-			count_profiles = na_object_get_items_count( window->private->selected_item );
-			/*g_return_if_fail( count_profiles >= 1 );*/
-
-			if( count_profiles == 1 ){
-				profiles = na_object_get_items( window->private->selected_item );
+			if( nb_profiles == 1 ){
+				profiles = na_object_get_items( selected_row );
 				window->private->selected_profile = NA_OBJECT_PROFILE( profiles->data );
 			}
 		}
 	}
-
-	set_current_profile( window, FALSE, selected_items );
-}
-
-static void
-set_current_profile( NactMainWindow *window, gboolean set_action, GSList *selected_items )
-{
-	static const gchar *thisfn = "nact_main_window_set_current_profile";
-
-	g_debug( "%s: window=%p, set_action=%s, selected_items=%p",
-			thisfn, ( void * ) window, set_action ? "True":"False", ( void * ) selected_items );
-
-	if( window->private->selected_profile && set_action ){
-
-		NAObjectAction *action = NA_OBJECT_ACTION( na_object_get_parent( window->private->selected_profile ));
-		NactApplication *application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
-		NAUpdater *updater = nact_application_get_updater( application );
-		window->private->selected_item = NA_OBJECT_ITEM( action );
-		window->private->editable = na_updater_is_item_writable( updater, window->private->selected_item, &window->private->reason );
-	}
-}
-
-static gchar *
-iactions_list_get_treeview_name( NactIActionsList *instance )
-{
-	gchar *name = NULL;
-
-	g_return_val_if_fail( NACT_IS_MAIN_WINDOW( instance ), NULL );
-
-	name = g_strdup( "ActionsList" );
-
-	return( name );
 }
 
 /*
@@ -1383,7 +1364,7 @@ setup_dialog_title( NactMainWindow *window )
 
 	if( window->private->selected_item ){
 		label = na_object_get_label( window->private->selected_item );
-		tmp = g_strdup_printf( "%s - %s", title, label );
+		tmp = g_strdup_printf( "%s - %s", label, title );
 		g_free( label );
 		g_free( title );
 		title = tmp;
@@ -1400,6 +1381,32 @@ setup_dialog_title( NactMainWindow *window )
 	g_free( title );
 }
 
+static void
+setup_writability_status( NactMainWindow *window )
+{
+	NactApplication *application;
+	NAUpdater *updater;
+
+	g_return_if_fail( NA_IS_OBJECT_ITEM( window->private->selected_item ));
+
+	application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
+	updater = nact_application_get_updater( application );
+	window->private->editable = na_updater_is_item_writable( updater, window->private->selected_item, &window->private->reason );
+	nact_main_statusbar_set_locked( window, !window->private->editable, window->private->reason );
+}
+
+static gchar *
+iactions_list_get_treeview_name( NactIActionsList *instance )
+{
+	gchar *name = NULL;
+
+	g_return_val_if_fail( NACT_IS_MAIN_WINDOW( instance ), NULL );
+
+	name = g_strdup( "ActionsList" );
+
+	return( name );
+}
+
 static void
 on_tab_updatable_item_updated( NactMainWindow *window, gpointer user_data, gboolean force_display )
 {
@@ -1566,10 +1573,27 @@ ipivot_consumer_on_display_order_changed( NAIPivotConsumer *instance, gint order
 	}
 }
 
+static void
+ipivot_consumer_on_io_provider_prefs_changed( NAIPivotConsumer *instance )
+{
+	update_ui_after_provider_change( NACT_MAIN_WINDOW( instance ));
+}
+
 static void
 ipivot_consumer_on_mandatory_prefs_changed( NAIPivotConsumer *instance )
 {
-	nact_sort_buttons_level_zero_writability_change( NACT_MAIN_WINDOW( instance ));
+	update_ui_after_provider_change( NACT_MAIN_WINDOW( instance ));
+}
+
+static void
+update_ui_after_provider_change( NactMainWindow *window )
+{
+	nact_sort_buttons_level_zero_writability_change( window );
+
+	if( window->private->selected_item ){
+		setup_writability_status( window );
+		g_signal_emit_by_name( window, MAIN_WINDOW_SIGNAL_SELECTION_CHANGED, GINT_TO_POINTER( 1 ));
+	}
 }
 
 static void
